function [xk,resxk] = gss(A,b,x0,toll,kmax)
%GSS metodo iterativo di Gauss-Seidel
%  [XK,RESXK] =GSS(A,B,X0,TOLL,KMAX) risolve
%  il sistema lineare AX=B col metodo di 
%  Jacobi usando un test di arresto sul 
%  residuo
%              || b-A*x(k) ||
%            ------------------<toll
%                  || b ||
%
%  XK e' una matrice che ha nella colonna
%  k-esima la iterata x(k-1), k=0,1,2,...
%  RESK e' il vettore dei residui che
%  contiene nella posizione k il residuo
%  relativo della iterata x(k-1).
%
%

xk(:,1)  = x0;
resxk(1) = norm(b-A*x0)/norm(b);
% creo le matrici di Jacobi EJ e qJ
% EJ = -inv(D)*(L+U) e qJ = inv(D)*b
L  = tril(A,-1); % parte sotto la diagonale
U  = triu(A, 1); % parte sopra la diagonale
D  = diag( diag(A) ); % diagonale
ES = -inv(D+L)*U;
qS =  inv(D+L)*b;

k =1;
while( resxk(k)>=toll && k<=kmax )
    % nuova iterazione di Jacobi
    k        = k+1;
    xk(:,k)  = ES*xk(:,k-1)+qS;
    resxk(k) = norm(b-A*xk(:,k))/norm(b);
end
