function [xk,resxk] = jac(A,b,x0,toll,kmax)
%JAC metodo iterativo di Jacobi
%  [XK,RESXK] =JAC(A,B,X0,TOLL,KMAX) risolve
%  il sistema lineare AX=B col metodo di 
%  Jacobi usando un test di arresto sul 
%  residuo
%              || b-A*x(k) ||
%            ------------------<toll
%                  || b ||
%
%  XK e' una matrice che ha nella colonna
%  k-esima la iterata x(k-1), k=0,1,2,...
%  RESK e' il vettore dei residui che
%  contiene nella posizione k il residuo
%  relativo della iterata x(k-1).
%
%


xk    = x0;
resxk(1) = norm(b-A*x0)/norm(b);
% creo le matrici di Jacobi EJ e qJ
% EJ = -inv(D)*(L+U) e qJ = inv(D)*b
L  = tril(A,-1); % parte sotto la diagonale
U  = triu(A, 1); % parte sopra la diagonale
D  = diag( diag(A) ); % diagonale
EJ = -inv(D)*(L+U);
qJ =  inv(D)*b;

k =1;
while( resxk(k)>=toll && k<=kmax )
    % nuova iterazione di Jacobi
    k        = k+1;
    xk(:,k)  = EJ*xk(:,k-1)+qJ;
    resxk(k) = norm(b-A*xk(:,k))/norm(b);
end















